/**
 * Created by jmoutard on 17/05/16.
 */

'use strict';

angular.module('adf.electre')
    .service('storeService', [
        "$http", "$q", "parserService",
        function ($http, $q, parserService) {
            /**
             * @description Return all stored dashboard from the server.
             * @returns {Promise}
             */
            function getAll () {
                var deferred = $q.defer();
                $http.get('/lavoisier/list_layout')
                    .success(function(data){
                        /* Getting :
                         * <?xml-stylesheet type="text/xsl" href="/lavoisier/xsl/list_layout"?>
                         * <properties>
                         *     <dashboard id="[Dashboard id]">[Dashboard title]</dashboard>
                         *     ...
                         * </properties>
                         * [Dashboard id] and [Dashboard title] as String
                         */
                        /* First thing parse from String to XML */
                        var data_ = parserService.xmlDomFromString(data);
                        /* Second thing organise [Dashboard id] and [Dashboard title] like a JSON object in an Array */
                        var data_js = [], dashboards = data_.getElementsByTagName("dashboard");
                        console.log(dashboards);
                        for (var d=0 ; d<dashboards.length ; d++) {
                            data_js.push({"id":dashboards[d].id, "title":dashboards[d].innerHTML});
                        }
                        console.log(data_js);
                        deferred.resolve(data_js);
                    })
                    .error(function(){
                        deferred.reject();
                    });
                return deferred.promise;
            }

            /**
             * @description Return a specific stored dashboard from the server.
             * @param {string} id
             * @returns {Promise}
             */
            function get (id) {
                var deferred = $q.defer();
                $http.get('/lavoisier/load_layout?layout_id=' + id)
                    .success(function(data){
                        /* Getting :
                         * <dashboard>{...}</dashboard>
                         */
                        /* First thing parse from String to XML */
                        var data_ = parserService.xmlDomFromString(data);
                        /* Second thing navigate into XMLDOM to get the data */
                        data_ = data_.firstElementChild.firstChild.data;
                        console.log(data_, JSON.parse(data_));
                        /* At last give the data requested parsed into JSON */
                        deferred.resolve(JSON.parse(data_));
                    })
                    .error(function(){
                        deferred.reject();
                    });
                return deferred.promise;
            }

            /**
             * @description Add a dashboard onto the server.
             * @param {string} id
             * @param {object} data
             * @returns {Promise}
             */
            function add (id, data) {
                var deferred = $q.defer();
                $http.get('/lavoisier/save_layout?layout_id=' + id + "&data=" + JSON.stringify(data))
                    .success(function(data){
                        deferred.resolve();
                    })
                    .error(function(){
                        deferred.reject();
                    });
                return deferred.promise;
            }

            /**
             * @description Remove a dashboard onto the server.
             * @param {string} id
             * @returns {Promise}
             */
            function remove (id) {
                var deferred = $q.defer();
                $http.delete('/lavoisier/delete_layout?layout_id=' + id)
                    .success(function(data){
                        deferred.resolve(data);
                    })
                    .error(function(){
                        deferred.reject();
                    });
                return deferred.promise;
            }

            return { getAll: getAll, get: get, add: add, remove: remove};
        }
    ])/*.service('loginService', [
        "$http", "$q",
        function ($http, $q) {
            /!**
             * @description Sign up to the app. Allow you to save your dashboards on the server.
             * @param {object} data User data.
             * @returns {c}
             *!/
            function signup (data) {
                var deferred = $q.defer();
                $http.post('/signup', data)
                    .success(function (value) {
                        deferred.resolve(value);
                    }).error(function () {
                        deferred.reject();
                    });
                return deferred.promise;
            }
            /!**
             * @description Log in the app. When logged in you can load your dashboards.
             * @param data
             * @returns {c}
             *!/
            function login (data) {
                var deferred = $q.defer();
                $http.post('/login', data)
                    .success(function (data) {
                        deferred.resolve(data);
                    }).error(function () {
                        deferred.reject();
                    });
                return deferred.promise;
            }
            /!**
             * @description Log out the app.
             * @returns {c}
             *!/
            function logout () {
                var deferred = $q.defer();
                $http.get('/logout')
                    .success(function () {
                        deferred.resolve();
                    }).error(function () {
                        deferred.reject();
                    });
                return deferred.promise;
            }

            return { signup: signup, login: login, logout: logout };
        }
    ])*/;